# obj-to-xml

Hassle-free creation of `HTML` and `XML` tags directly from `JavaScript` objects with any level of nesting.

## Purpose
- If you want to create HTML tags from JavaScript, you can directly create those to any level of nesting using JavaScript objects and append it to the document. This will be the easiest way to do it.
- If you're working on an application which supports XML as a data interchange format in REST API's, this package can be used to create an XML using JavaScript objects while sending data to the server.

## Installation

```sh
$ npm install obj-to-xml
```

## API

```js
var objToXml = require('obj-to-xml');
```

### objToXml.buildXmlFromObj(object, toString)

#### @param: object

Pass in the JavaScript object which has to be converted to HTML/XML. Object's property which is defined with `@`, is treated as an "attribute".

#### @param: toString (Boolean) [optional]

- `true` Returns HTML/XML as string.
- `false` Returns HTML/XML as document element. 
Defaults to `false`.

##### Usage

```js
var objToXml = require("obj-to-xml");
var obj = {
    ROOT: {
        R: {
            "@id": 1
        }
    }
}
objToXml.buildXmlFromObj(obj);
/* Returns XML as document element, since toString is undefined.
<ROOT> <R id="1"/> </ROOT> */

objToXml.buildXmlFromObj(obj, true);
/* Returns XML as string, since toString is true.
"<ROOT> <R id="1"/> </ROOT>" */

```

To get a list of items, pass an array as value to the object's property.

```js
var objToXml = require("obj-to-xml");
var obj = {
    STUDENTS: {
        S: [{
            "@id": 1,
            "@name": "Nandeesh"
        }, {
            "@id": 2,
            "@name": "Stanley"
        }]
    }
}
objToXml.buildXmlFromObj(obj);
/* returns an XML,
<STUDENTS>
	<S id="1" name="Nandeesh"/>
	<S id="2" name="Stanley"/>
</STUDENTS>
*/

```

To add a text content to the tag, set `#textContent#` property to the object.

```js
var objToXml = require("obj-to-xml");
var obj = {
    ROOT: {
        R: {
            "@id": 1,
			"#textContent#": "Lorem Ipsum"
        }
    }
}
objToXml.buildXmlFromObj(obj);
/* Returns an XML,
<ROOT>
	<R id="1">"Lorem Ipsum"</R>
</ROOT> */

```
Similarly, to create HTML tags define the structure as an object.

```js
var objToXml = require("obj-to-xml");
var obj = {
    button: {
        "@type": "button",
        "@id": "tag-id",
        "@class": "my-css-class",
        "@style": "background:green;",
        "@onclick": "alert('Hello world!')",
        "#textContent#": "Hurray! Button from object"
    }
}
var btnEl = objToXml.buildXmlFromObj(obj);
document.body.appendChild(btnEl);
/* Returns HTML button element,
<button type="button" id="tag-id" class="my-css-class" style="background:green;" onclick="alert('Hello world!')">"Hurray! Button from object"</button> */

```
### NOTE:
This package can be used only for client-side applications like ReactJS/ AngularJS etc.